package com.example.beijingnopowercon.ui.home;

import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Toast;

import androidx.annotation.NonNull;

import com.example.beijingnopowercon.CustomScannerActivity;
import com.example.beijingnopowercon.adapter.DeviceListAdapter;
import com.example.beijingnopowercon.base.BaseFragment;
import com.example.beijingnopowercon.data.DeviceInfo;
import com.example.beijingnopowercon.databinding.FragmentHomeBinding;
import com.example.beijingnopowercon.dialog.SanInfoDialog;
import com.example.beijingnopowercon.okgo.MyRecultCall;
import com.example.beijingnopowercon.okgo.MyResult;
import com.example.beijingnopowercon.uitls.SharedPreferencesUtils;
import com.google.android.material.snackbar.Snackbar;
import com.google.gson.reflect.TypeToken;
import com.google.zxing.integration.android.IntentIntegrator;
import com.google.zxing.integration.android.IntentResult;
import com.lzy.okgo.OkGo;
import com.lzy.okgo.model.Response;
import com.scwang.smart.refresh.layout.SmartRefreshLayout;

import java.util.List;

import okhttp3.MediaType;
import okhttp3.RequestBody;

public class HomeFragment extends BaseFragment implements SanInfoDialog.SanInfoDialogCall {
    private View root;
    private FragmentHomeBinding binding;
    private SanInfoDialog infoDialog;
    private DeviceListAdapter adapter;

    public View onCreateView(@NonNull LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        binding = FragmentHomeBinding.inflate(inflater, container, false);
        root = binding.getRoot();
        binding.homeSan.setOnClickListener(v -> {
            Intent intent = new Intent(getActivity(), CustomScannerActivity.class);
            startActivityForResult(intent, IntentIntegrator.REQUEST_CODE);
        });
        infoDialog = new SanInfoDialog(context);
        infoDialog.setCall(this);
        adapter = new DeviceListAdapter(context);
        binding.homeRcyler.setAdapter(adapter);
        SmartRefreshLayout inventoryCreateRefresh = binding.inventoryCreateRefresh;
        inventoryCreateRefresh.setEnableRefresh(true);
        // 设置下拉刷新监听器
        inventoryCreateRefresh.setOnRefreshListener(refreshLayout -> {
            // 执行刷新操作，例如重新加载数据
            initRequest();
            // 刷新完成后调用此方法
            refreshLayout.finishRefresh();
        });
        initRequest();
        Log.e("TAG", "onCreateView:");
        return root;
    }

    private void initRequest() {
        OkGo.<MyResult>post(url + "/home/selectDeviceInfoList").execute(new MyRecultCall(dialog, context) {
            @Override
            public void onSuccess(Response<MyResult> response) {
                super.onSuccess(response);
                MyResult body = response.body();
                if (body.getCode() == 0) {
                    List<DeviceInfo> list = gson.fromJson(body.getDataJson(), new TypeToken<List<DeviceInfo>>() {
                    }.getType());
                    adapter.setList(list);
                    adapter.notifyDataSetChanged();
                    return;
                }
                Toast.makeText(context, body.getMsg(), Toast.LENGTH_SHORT).show();
            }
        });
    }

    @Override
    public void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if (requestCode == IntentIntegrator.REQUEST_CODE) {
            IntentResult result = IntentIntegrator.parseActivityResult(requestCode, resultCode, data);
            if (result != null) {
                if (result.getContents() == null) {
                    Snackbar.make(root, "扫描取消", Snackbar.LENGTH_LONG).show();
                } else {
                    // Toast.makeText(context, "扫描成功", Toast.LENGTH_SHORT).show();
                    selectDeviceInfo(result.getContents());
                }
            }
        }
    }

    // 查询设备
    private void selectDeviceInfo(String code) {
        OkGo.<MyResult>post(url + "/home/selectDeviceInfo").params("code", code).execute(new MyRecultCall(dialog, context) {
            @Override
            public void onSuccess(Response<MyResult> response) {
                super.onSuccess(response);
                MyResult body = response.body();
                if (body.getCode() == 0) {
                    DeviceInfo deviceInfo = gson.fromJson(body.getDataJson(), DeviceInfo.class);
                    Log.e("TAG", "onSuccess:请求成功");
                    infoDialog.setDeviceInfo(deviceInfo);
                    infoDialog.show();
                    return;
                }
                Toast.makeText(context, body.getMsg(), Toast.LENGTH_SHORT).show();
            }
        });
    }


    @Override
    public void onDestroyView() {
        super.onDestroyView();
        binding = null;
    }


    @Override
    public void openDeviceLockRequest(DeviceInfo deviceInfo) {
        deviceInfo.setUserId(SharedPreferencesUtils.getLong("userId", 0L));
        deviceInfo.setDeptId(SharedPreferencesUtils.getLong("deptId", 0L));
        deviceInfo.setUseUser(SharedPreferencesUtils.getstring("user", null));
        OkGo.<MyResult>post(url + "/home/openDeviceLock").upRequestBody(RequestBody.create(MediaType.parse("application/json; charset=utf-8"), gson.toJson(deviceInfo))).execute(new MyRecultCall(dialog, context) {
            @Override
            public void onSuccess(Response<MyResult> response) {
                super.onSuccess(response);
                MyResult body = response.body();
                if (body.getCode() == 0) {
                    Toast.makeText(context, "开锁成功", Toast.LENGTH_SHORT).show();
                    infoDialog.dismiss();
                    initRequest();
                    return;
                }
                Toast.makeText(context, body.getMsg(), Toast.LENGTH_LONG).show();
            }
        });
    }
}